==> humhub-1.14.5.tar.gz: humhub-1.14.5/protected/humhub/modules/content/messages/ar/base.php <==
<?php

return [
    '<strong>Confirm</strong> post deletion' => '<strong>تأكيد</strong> رغبتك في الحذف',
    '<strong>Move</strong> content' => 'محتوى <strong> نقل </strong>',
    '<strong>Permalink</strong> to this post' => 'الوصلة الدائمة لهذه المحتويات',
    'Activated' => 'تم التفعيل',
    'Add a member to notify' => 'إضافة عضو للتنبيه',
    'Archived' => 'أرشيف',
    'Back to stream' => 'العودة للمحتويات',
    'Cancel' => 'إلغاء',
    'Cancel Edit' => 'إلغاء تحرير',
    'Change to "Private"' => 'إجعله خاص',
    'Change to "Public"' => 'إجعله عام',
    'Configure' => 'إعدادات',
    'Confirm' => 'أكد',
    'Content' => 'المحتوى',
    'Content Tag with invalid contentcontainer_id assigned.' => 'تم تعيين علامة المحتوى مع contentcontainer_id غير صالح.',
    'Content has been moved to {spacename}' => 'تم نقل المحتوى إلى {spacename}',
    'Could not find requested content!' => 'لم يتم إيجاد المحتويات المطلوبة!',
    'Created by me' => 'التي كتبتها أنا',
    'Creation time' => 'حسب وقت النشر',
    'Delete' => 'حذف',
    'Do you really want to delete this post? All likes and comments will be lost!' => 'هل انت متأكد من رغبتك في حذف هذه المحتويات؟ جميع الردود و نقاط الإعجاب ستختفي!',
    'Edit' => 'تحرير',
    'Enable' => 'تفعيل',
    'Filter' => 'تصفية',
    'I\'m involved' => 'أين أنا متورط',
    'Invalid content id given!' => 'تم تقديم معرف محتوى غير صالح!',
    'Invalid request method!' => 'طريقة الطلب غير صالحة!',
    'Invalid space selection.' => 'تحديد مساحة غير صالح.',
    'Last update' => 'حسب آخر تعديل',
    'Load more' => 'تحميل المزيد',
    'Move content' => 'انقل المحتوى',
    'Move to archive' => 'نقل للأرشيف',
    'No matches with your selected filters!' => 'لم يتم إيجاد نتائج مطابقة للبحث',
    'None' => 'لا يوجد',
    'Nothing here yet!' => 'لا يوجد شيء هنا بعد!',
    'Notify members' => 'إرسال تنبيه للأعضاء',
    'Permalink' => 'وصلة دائمة',
    'Pin to top' => 'دبوس الى أعلى الصفحة',
    'Pinned' => 'مثبت',
    'Private' => 'خاص',
    'Public' => 'عام',
    'Submit' => 'أرسل',
    'Tag' => 'بطاقة شعار',
    'Target Space' => 'الهدف الهدف',
    'The author of this content is not allowed to create private content within the selected space.' => 'لا يسمح لمؤلف هذا المحتوى بإنشاء محتوى خاص ضمن المساحة المحددة.',
    'The author of this content is not allowed to create public content within the selected space.' => 'لا يسمح لمؤلف هذا المحتوى بإنشاء محتوى عام ضمن المساحة المحددة.',
    'The content can\'t be moved to its current space.' => 'لا يمكن نقل المحتوى إلى مساحته الحالية.',
    'The content has been archived.' => 'تم أرشفة المحتوى.',
    'The content has been deleted.' => 'تم حذف المحتوى.',
    'The content has been unarchived.' => 'تم إخراج المحتوى من الأرشيف.',
    'The given name is already in use.' => 'الاسم المحدد قيد الاستخدام بالفعل.',
    'The module {moduleName} is not enabled on the selected target space.' => 'الوحدة النمطية {moduleName} غير ممكّنة على المساحة المستهدفة المحددة.',
    'This action is disabled!' => 'هذا الإجراء معطل!',
    'This content type can\'t be moved due to a missing module-id setting.' => 'لا يمكن نقل نوع المحتوى هذا بسبب عدم وجود إعداد معرف الوحدة النمطية.',
    'This content type can\'t be moved.' => 'This content type can\'t be moved.',
    'This space is archived.' => 'تمت أرشفة هذه المساحة.',
    'This space is not visible!' => 'هذه المساحة غير مرئية!',
    'Topics' => 'المواضيع',
    'Turn off notifications' => 'إلغاء التنبيهات',
    'Turn on notifications' => 'تفعيل التنبيهات',
    'Unarchive' => 'إلغاء وضع الأرشيف',
    'Unpin' => 'إلغاء التثبيت',
    'Updated' => 'محدث',
    'With attachments' => 'مع مرفقات الملف',
    'You do not have the permission to move this content to the given space.' => 'ليس لديك إذن بنقل هذا المحتوى إلى المساحة المحددة.',
    'You do not have the permission to move this content.' => 'ليس لديك إذن بنقل هذا المحتوى.',
    'Your last edit state has been saved!' => 'تم حفظ آخر حالة تحرير لك!',
    'in' => 'في',
    '(Also visible to non-members of this space)' => '',
    '<strong>Delete</strong> content?' => '',
    '<strong>Scheduling</strong> Options' => '',
    'Activate scheduling' => '',
    'Add tag...' => '',
    'Attach Files' => '',
    'Cannot notify the author.' => '',
    'Comments are locked' => '',
    'Comments are unlocked' => '',
    'Create as draft' => '',
    'Created at:' => '',
    'Deleted' => '',
    'Draft' => '',
    'Hidden' => '',
    'Last updated {time}' => '',
    'Lock comments' => '',
    'Maximum number of pinned items reached!<br>You can only pin up to {count} items at once.' => '',
    'New Updates Available!' => '',
    'No tags found for the given query' => '',
    'Note: Due to technical reasons there may be a delay of a few minutes.' => '',
    'Publish draft' => '',
    'Schedule publication' => '',
    'Scheduled at {dateTime}' => '',
    'Select type...' => '',
    'Specify who can see this content.' => '',
    'The author of this content is not allowed to create this type of content within this space.' => '',
    'The content has been successfully published.' => '',
    'Unlock comments' => '',
    'Visible also to unregistered users' => '',
    'Visible only to you' => '',
    'Visible to all Space members' => '',
    'Visible to all signed in users' => '',
    'Visible to friends of {displayName}' => '',
    'Visible to you and {displayName}' => '',
    'Visible to your friends' => '',
    'You cannot block the space owner!' => '',
    'You cannot block the user of the same container!' => '',
    'You cannot block yourself!' => '',
];

==> humhub-1.15.3.tar.gz: humhub-1.15.3/protected/humhub/modules/content/messages/ar/base.php <==
<?php

return [
    '<strong>Move</strong> content' => 'محتوى <strong> نقل </strong>',
    '<strong>Permalink</strong> to this post' => 'الوصلة الدائمة لهذه المحتويات',
    'Activated' => 'تم التفعيل',
    'Add a member to notify' => 'إضافة عضو للتنبيه',
    'Archived' => 'أرشيف',
    'Back to stream' => 'العودة للمحتويات',
    'Cancel' => 'إلغاء',
    'Cancel Edit' => 'إلغاء تحرير',
    'Change to "Private"' => 'إجعله خاص',
    'Change to "Public"' => 'إجعله عام',
    'Configure' => 'إعدادات',
    'Confirm' => 'أكد',
    'Content' => 'المحتوى',
    'Content Tag with invalid contentcontainer_id assigned.' => 'تم تعيين علامة المحتوى مع contentcontainer_id غير صالح.',
    'Content has been moved to {spacename}' => 'تم نقل المحتوى إلى {spacename}',
    'Could not find requested content!' => 'لم يتم إيجاد المحتويات المطلوبة!',
    'Created by me' => 'التي كتبتها أنا',
    'Creation time' => 'حسب وقت النشر',
    'Delete' => 'حذف',
    'Edit' => 'تحرير',
    'Enable' => 'تفعيل',
    'Filter' => 'تصفية',
    'I\'m involved' => 'أين أنا متورط',
    'Invalid content id given!' => 'تم تقديم معرف محتوى غير صالح!',
    'Invalid request method!' => 'طريقة الطلب غير صالحة!',
    'Invalid space selection.' => 'تحديد مساحة غير صالح.',
    'Last update' => 'حسب آخر تعديل',
    'Load more' => 'تحميل المزيد',
    'Move content' => 'انقل المحتوى',
    'Move to archive' => 'نقل للأرشيف',
    'No matches with your selected filters!' => 'لم يتم إيجاد نتائج مطابقة للبحث',
    'None' => 'لا يوجد',
    'Nothing here yet!' => 'لا يوجد شيء هنا بعد!',
    'Notify members' => 'إرسال تنبيه للأعضاء',
    'Permalink' => 'وصلة دائمة',
    'Pin to top' => 'دبوس الى أعلى الصفحة',
    'Pinned' => 'مثبت',
    'Private' => 'خاص',
    'Public' => 'عام',
    'Submit' => 'أرسل',
    'Tag' => 'بطاقة شعار',
    'Target Space' => 'الهدف الهدف',
    'The author of this content is not allowed to create private content within the selected space.' => 'لا يسمح لمؤلف هذا المحتوى بإنشاء محتوى خاص ضمن المساحة المحددة.',
    'The author of this content is not allowed to create public content within the selected space.' => 'لا يسمح لمؤلف هذا المحتوى بإنشاء محتوى عام ضمن المساحة المحددة.',
    'The content can\'t be moved to its current space.' => 'لا يمكن نقل المحتوى إلى مساحته الحالية.',
    'The content has been archived.' => 'تم أرشفة المحتوى.',
    'The content has been deleted.' => 'تم حذف المحتوى.',
    'The content has been unarchived.' => 'تم إخراج المحتوى من الأرشيف.',
    'The given name is already in use.' => 'الاسم المحدد قيد الاستخدام بالفعل.',
    'The module {moduleName} is not enabled on the selected target space.' => 'الوحدة النمطية {moduleName} غير ممكّنة على المساحة المستهدفة المحددة.',
    'This action is disabled!' => 'هذا الإجراء معطل!',
    'This content type can\'t be moved due to a missing module-id setting.' => 'لا يمكن نقل نوع المحتوى هذا بسبب عدم وجود إعداد معرف الوحدة النمطية.',
    'This content type can\'t be moved.' => 'This content type can\'t be moved.',
    'This space is archived.' => 'تمت أرشفة هذه المساحة.',
    'This space is not visible!' => 'هذه المساحة غير مرئية!',
    'Topics' => 'المواضيع',
    'Turn off notifications' => 'إلغاء التنبيهات',
    'Turn on notifications' => 'تفعيل التنبيهات',
    'Unarchive' => 'إلغاء وضع الأرشيف',
    'Unpin' => 'إلغاء التثبيت',
    'Updated' => 'محدث',
    'With attachments' => 'مع مرفقات الملف',
    'You do not have the permission to move this content to the given space.' => 'ليس لديك إذن بنقل هذا المحتوى إلى المساحة المحددة.',
    'You do not have the permission to move this content.' => 'ليس لديك إذن بنقل هذا المحتوى.',
    'Your last edit state has been saved!' => 'تم حفظ آخر حالة تحرير لك!',
    'in' => 'في',
    '(Also visible to non-members of this space)' => '',
    '<strong>Delete</strong> content?' => '',
    '<strong>Scheduling</strong> Options' => '',
    'Activate scheduling' => '',
    'Add tag...' => '',
    'Attach Files' => '',
    'Cannot notify the author.' => '',
    'Comments are locked' => '',
    'Comments are unlocked' => '',
    'Create as draft' => '',
    'Created at:' => '',
    'Deleted' => '',
    'Do you want to delete this content, including all comments and attachments?<br><br>Please note: If a stream entry was created using a module, the original content that this entry is linked to will also be deleted.' => '',
    'Draft' => '',
    'Hidden' => '',
    'Last updated {time}' => '',
    'Lock comments' => '',
    'Maximum number of pinned items reached!<br>You can only pin up to {count} items at once.' => '',
    'New Updates Available!' => '',
    'No tags found for the given query' => '',
    'Note: Due to technical reasons there may be a delay of a few minutes.' => '',
    'Publish draft' => '',
    'Save as draft' => '',
    'Save scheduling' => '',
    'Schedule publication' => '',
    'Scheduled for {dateTime}' => '',
    'Select type...' => '',
    'Specify who can see this content.' => '',
    'The author of this content is not allowed to create this type of content within this space.' => '',
    'The content cannot be published!' => '',
    'The content has been successfully published.' => '',
    'Unlock comments' => '',
    'Visible also to unregistered users' => '',
    'Visible only to you' => '',
    'Visible to all Space members' => '',
    'Visible to all signed in users' => '',
    'Visible to friends of {displayName}' => '',
    'Visible to you and {displayName}' => '',
    'Visible to your friends' => '',
    'You cannot block the space owner!' => '',
    'You cannot block the user of the same container!' => '',
    'You cannot block yourself!' => '',
];
